/**
 * object storing data about biofilm structure (basic geometry)
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class BiofilmStruct
{
    /**
     * variables and parameters
     */
    // variables
    private double depthPrev;
    private double depthCurr;
    private double susceptPrev;
    private double susceptCurr;
    // parameters
    private double occupancy;
    private double cellDiameter;
    private double crossArea;

    public BiofilmStruct(double inidepthCurr, double inisusceptCurr, double poccupancy, double pcellDiameter, double pcrossArea)
    {
        depthCurr = inidepthCurr;
        susceptCurr = inisusceptCurr;
        occupancy = poccupancy;
        cellDiameter = pcellDiameter;
        crossArea = pcrossArea;
    }

     /**
     * accessor methods
     */
    public double getDepth(){
        return depthCurr;
    }

    public double getSuscept(){
        return susceptCurr;    
    }
    
    /**
     * core methods
     */
    // update method
    public double updateDepth(double diffBT)
    {
        depthPrev = depthCurr;
        depthCurr += Math.pow(occupancy + cellDiameter, 3) / crossArea * diffBT;
        if(depthCurr < 0){
            depthCurr = 0;
        }
        return depthCurr;
    }
    
    public double updateSuscept(double phageLayer){
        susceptPrev = susceptCurr;
        if(phageLayer < depthCurr){
            susceptCurr = phageLayer / depthCurr;
        }else{
            susceptCurr = 1;
        }
        return susceptCurr;
    }
}