/**
 * object storing data about diffusion process
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
import java.lang.Math;

public class Diffusion
{
    // state
    private double rInPrev;
    private double rIn;
    private double phageLayerPrev;
    private double phageLayer;
    private double washOffRatePrev;
    private double washOffRate;
    
    // parameters
    private double rMin;
    private double rMax;
    private double rOut;
    private double Y;
    
    public Diffusion(double inirIn, double prMin, double prMax, double prOut, double pY)
    {
        rIn = inirIn;
        rInPrev = inirIn;
        phageLayer = 0;
        rMin = prMin;
        rMax = prMax;
        rOut = prOut;
        Y = pY;
        washOffRate = rOut / (rIn + rOut);
    }

    /**
     * accessor methods
     */
    public double getRatePrev()
    {
        return rInPrev;
    }

    public double getRate()
    {
        return rIn;
    }

    public double getPhageLayerPrev()
    {
        return phageLayerPrev;
    }

    public double getPhageLayer()
    {
        return phageLayer;
    }

    public double getWashOffRatePrev()
    {
        return washOffRatePrev;
    }

    public double getWashOffRate()
    {
        return washOffRate;
    }

     /**
     * core methods
     */
    public double updateRate(double diffDspB)
    {
        // update
        rInPrev = rIn;
        //
        rIn += Y * diffDspB;
        if(rIn < rMin){
            rIn = rMin;
        }else if(rIn > rMax){
            rIn = rMax;
        }
        // return value
        return rIn;
    }
    
    public double updatePhageLayer(){
        // update
        phageLayerPrev = phageLayer;
        //
        phageLayer = 2 * Math.sqrt(rInPrev);
        // return value
        return phageLayer;
    }
    
    public double updateWashOffRate(){
        // update
        washOffRatePrev = washOffRate;
        //
        washOffRate = rOut / (rInPrev + rOut);
        // return value
        return washOffRate;
    }
}