/**
 * object storing data about DspB concentration inside biofilm
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class DspB
{
    // state
    private double DspBprev;
    private double DspB;
    // parameters
    private double productRateS;
    
    public DspB(double iniDspB, double pProductRateS)
    {
        DspB = iniDspB;
        productRateS = pProductRateS;
    }

    // accessor methods
    public double getDspBprev()
    {
        return DspBprev;
    }

    public double getDspB()
    {
        return DspB;
    }

    // update method
    public double updateDspB(double washOffRate, double Bl, double lysisRate, double aip, double aipThres)
    {
        // update
        DspBprev = DspB;
        // terms
        double term1 = -washOffRate * DspB;
        double term2 = productRateS * getTermZ(Bl, lysisRate, aip, aipThres);
//        System.out.println(Bl +" "+ lysisRate +" "+ aip +" "+ aipThres);
//        System.out.println(getTermZ(Bl, lysisRate, aip, aipThres));
        DspB += term1 + term2;
        if(DspB < 0){
            DspB = 0;
        }
        // return value
        return DspB;
    }

    // calculate term representing AIP activation
    public double getTermZ(double Bl, double lysisRate, double aip, double aipThres){
        if(aip < aipThres){
            return 0;
        }else{
            return lysisRate * Bl;
        }
    }

}