/**
 * object storing data about infected biofilm subpopulation
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class LatentBiofilmPop extends InfectedBiofilmPop
{
    /**
     * variables and parameters
     */
    public LatentBiofilmPop(double inipopCount, double pgrowthRateI, double pcarryCap, double plysisRate,  double pconvRate, double pportionLytic)
    {
        super(inipopCount, pgrowthRateI, pcarryCap, plysisRate);
        convRate = convRate;
        portionLytic = portionLytic;
    }

    /**
     * overloads parent method
     */
    public double updatePopCount(double BT, double Bi, double P, double eps, double kappa)
    {
        // return 1 if update is successful
        popCountPrev = popCount;
        // difference equation describing update for infected biofilm subpopulation size
        double term1 = (1 - portionLytic) * growthRateI * Bi * (1 - BT/carryCap);
        double term2 = (1 - portionLytic) * getTheta(BT, Bi, eps) * getTermX(BT, P, eps, kappa);
        double term3 = convRate * popCount;
        popCount += term1 + term2 + term3;
        // if popCount is less than 1, it's effectively 0
        if(popCount < 1){
            popCount = 0;
        }
        // return updated value
        return popCount;
    }
}