/**
 * object storing data about biofilm subpopulation infected with phage in lytic cycle
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class LyticBiofilmPop extends InfectedBiofilmPop
{
    /**
     * variables and parameters
     */
    public LyticBiofilmPop(double inipopCount, double pgrowthRateI, double pcarryCap, double plysisRate, double pconvRate, double pportionLytic)
    {
        super(inipopCount, pgrowthRateI, pcarryCap, plysisRate);
        convRate = pconvRate;
        portionLytic = pportionLytic;
    }

    /**
     * overloads parent method
     */
    public double updatePopCount(double BT, double Bi, double Bl, double BL, double P, double eps, double kappa)
    {
        // return 1 if update is successful
        popCountPrev = popCount;
        // difference equation describing update for infected biofilm subpopulation size
        double term1 = portionLytic * growthRateI * Bi * (1 - BT/carryCap);
        double term2 = portionLytic * getTheta(BT, Bi, eps) * getTermX(BT, P, eps, kappa);
        double term3 = -lysisRate*Bl;
        double term4 = convRate*BL;
        popCount += term1 + term2 + term3 + term4;
        // if popCount is less than 1, it's effectively 0
        if(popCount < 1){
            popCount = 0;
        }
        // return updated value
        return popCount;
    }
}