/**
 * object storing data about diffusion process
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
import java.io.*;
import java.lang.String;
import java.util.Scanner;
import java.util.HashMap;
import java.util.regex.*;   // require Pattern and Match classes
import java.lang.Double;

public class Parameters
{
    // info
    private String fileName;
    private HashMap parSet = new HashMap();
    private static final String fREGEP = "([\\w]+)=([\\d\\.]+)";
    // parameter list
/**
    private double growthRateU;
    private double growthRateI;
    private double carryCap;
    private double lysisRate;
    private double convRate;
    private double portionLytic;
    private double halfLife;
    private double infectRate;
    private double productRateR;
    private double rMin;
    private double rMax;
    private double rOut;
    private double Y;
    private double sigmaRate;
    private double gammaRate;
    private double AIPmax;
    private double AIPthres;
    private double productRateS;
    private double occupancy;
    private double cellDiameter;
    private double crossArea;
**/

    public Parameters(String SfileName)
    {
        fileName = SfileName;
        try{
            parseParFile( fileName );
        }catch(FileNotFoundException f){
            System.out.println("Failed to find " + fileName + ": " + f.getMessage());
        }
    }
    
    /**
     * accessor methods
     */
    public double get(String parName){
        try{
            return ( (Double) (parSet.get( parName ))).doubleValue();
        }catch(NullPointerException e){
            return 0.0000;
        }
    }
    
    /**
     * core methods
     */
    private final void parseParFile(String fileName) throws FileNotFoundException
    {
        File file = new File(fileName);
        Scanner parser = new Scanner( new FileReader(file) );
        Pattern pattern = Pattern.compile( fREGEP );
        Matcher matcher;

        try{
            System.out.println("=== setting parameter values from file ===");
            while( parser.hasNextLine() ){
                // parse line and then store value
                matcher = pattern.matcher( parser.nextLine() );
                if( matcher.matches() ){
                    String key = matcher.group(1);
                    Double val = new Double(matcher.group(2));
                    parSet.put( key, val);
                    System.out.println("...set " + key + " to " + val.doubleValue());
                }else{
                    System.out.println("BAD parameter parameter file format...");
                }
            }
            System.out.println("=== finished setting parameters ===");
        }finally{
            parser.close();
        }
    }
}