/**
 * object storing data about phage population
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class PhagePop
{
    /**
     * variables and parameters
     */
    // variables
    private double popCountPrev;
    private double popCount;
    // parameters
    private double halfLife;
    private double infectRate;
    private double productRateR;
    
    public PhagePop(double inipopCount, double phalfLife, double pinfectRate, double pproductRateR)
    {
        popCount = inipopCount;
        halfLife = phalfLife;
        infectRate = pinfectRate;
        productRateR = pproductRateR;
    }

    /**
     * accessor methods
     */
    public double getPopCountPrev()
    {
        return popCountPrev;
    }

    public double getPopCount()
    {
        return popCount;
    }

    /**
     * core methods
     */
    // update method
    public double updatePopCount(double BT, double Bl, double washOffRate, double eps, double lysisRate, double aip, double aipThres)
    {
        // update
        popCountPrev = popCount;
        // equation describing dynamics of phage population
        double term1 = -Math.log(2) / halfLife * popCount;
        double term2 = -washOffRate * popCount;
        double term3 = -getTermX(BT, popCount, eps, infectRate);
        double term4 = productRateR * getTermZ(Bl, lysisRate, aip, aipThres);
//        System.out.println(Bl +" "+ lysisRate +" "+ aip +" "+ aipThres);
//        System.out.println(getTermZ(Bl, lysisRate, aip, aipThres));
        popCount += term1 + term2 + term3 + term4;
        if(popCount < 1){
            popCount = 0;
        }
        // return updated pop. count
        return popCount;
    }

    // calculate term representing number of biofilm bacteria susceptible to infection and re-infection
    public double getTermX(double BT, double P,  double eps, double kappa){
        double term1 = kappa * P;
        double term2 = eps * BT;
        if(term1 <= term2){
            return term1;
        }else{
            return term2;
        }
    }

    // calculate term representing AIP activation
    public double getTermZ(double Bl, double lysisRate, double aip, double aipThres){
        if(aip < aipThres){
            return 0;
        }else{
            return lysisRate * Bl;
        }
    }
}