/**
 * PhilmGUI - main class and gui for simulation program
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
import java.io.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

public class PhilmGUI extends JFrame
{
    // constants
    private static final String TITLE = "UBC 2010 iGEM team - PhilmIt-v1.0";
    private static final String newline = System.getProperty("line.separator");

    // fields
    private String fileName;    // set pathname of parameter file
    private Parameters parSet;  // set parameter set from file
    
    // components
    private JFileChooser fileChooser = new JFileChooser();
    private JTextField displayField;
    private JTextArea outputArea;
    
    // actions
    private Action _openAction = new OpenAction();
    private Action _closeAction = new CloseAction();
    private Action _helpAction = new HelpAction();
    private Action _aboutAction = new AboutAction();
    
    // instances
    Philm simulator;
    JPanel content = new JPanel();
    JButton start = new JButton("Run Simulation");
    
    public PhilmGUI()
    {
        super(TITLE);

        // menu bar
        JMenuBar menuBar = new JMenuBar();
        JMenu fileMenu = menuBar.add(new JMenu("File"));
        fileMenu.add(_openAction);
        fileMenu.addSeparator();
        fileMenu.add(_closeAction);
        JMenu helpMenu = menuBar.add(new JMenu("Help"));
        helpMenu.add(_helpAction);
        helpMenu.add(_aboutAction);
        
        // display field
        JScrollPane scrollingText = new JScrollPane(outputArea);
        displayField = new JTextField("Number of Generations", 15);
        displayField.setHorizontalAlignment(JTextField.CENTER);
        outputArea = new JTextArea(40, 60);
        content.add(displayField);
        content.add(start);
        content.add(scrollingText, BorderLayout.CENTER);
        start.addActionListener(new RunAction());
        content.add(outputArea);
        
        // set content and menu
        setJMenuBar(menuBar);
        setContentPane(content);
        
        // window properties
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(750, 750);
        setVisible(true);
    }

    // main
    public static void main(String[] args){
        JFrame sim = new PhilmGUI();
    }
    
    // inner classes
    class OpenAction extends AbstractAction{
        public OpenAction(){
            super("Open File");
        }
        
        public void actionPerformed(ActionEvent e){
            int val = fileChooser.showOpenDialog(PhilmGUI.this);
            if(val == JFileChooser.APPROVE_OPTION){
                File file = fileChooser.getSelectedFile();
                parSet = new Parameters(file.getPath());
                simulator = new Philm(parSet);
            }
        }
    }
    
    class CloseAction extends AbstractAction{
        public CloseAction(){
            super("Close");
        }
        
        public void actionPerformed(ActionEvent e){
            System.out.println("...exiting PhilmIt-v1.0...");
            System.exit(0);
        }
    }
    
    class HelpAction extends AbstractAction{
        public HelpAction(){
            super("Help");
        }
        
        public void actionPerformed(ActionEvent e){
            System.out.println("Help: not yet available");
        }
    }
    
    // get About information from this action
    class AboutAction extends AbstractAction{
        public AboutAction(){
            super("About");
        }
        
        public void actionPerformed(ActionEvent e){
            System.out.println("============== UBC 2010 iGEM team ====================");
            System.out.println("=== PhilmIt-v1.0                                   ===");
            System.out.println("=== last update - Oct. 27, 2010                    ===");
            System.out.println("=== coder: Shing Hei Zhan                          ===");
            System.out.println("=== If you have questions regarding this software, ===");
            System.out.println("===    or would like to report bugs                ===");
            System.out.println("=== please contact:                                ===");
            System.out.println("===         shing<dot>zhan<at>gmail<dot>com        ===");
            System.out.println("======================================================");
        }
    }
    
    // run simulation from this action
    class RunAction implements ActionListener{
        public void actionPerformed(ActionEvent e){
            int gens = (new Integer(displayField.getText())).intValue();
            outputArea.append("===================== simulation results =====================" + newline);
            outputArea.append("gen" +"	"+ "percBiofilmLeft" +"	"+ "percBiofilmInfected" +"	"+ "Pfactor" +"	"+ "AIP" +"	"+ "DspB" + newline);
            simulator = new Philm(parSet);
            String results = simulator.printResults(simulator.run( gens + 1));
            outputArea.append(results);
        }
    }
}