/**
 * object storing data about total biofilm population
 * serves as the parent class to subpop. 1) uninfected, 2) infected, 3) lytic, and 4) latent
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class TotalBiofilmPop
{
    /**
     * variables and parameters
     */
    // population count, current and previous
    public double popCount;
    public double popCountPrev;
    // parameters
    public double growthRateU;
    public double growthRateI;
    public double carryCap;
    public double lysisRate;
    public double convRate;
    public double portionLytic;
    
    public TotalBiofilmPop(double inipopCount, double pgrowthRateU, double pgrowthRateI, double pcarryCap, double plysisRate)
    {
        popCount = inipopCount;
        growthRateU = pgrowthRateU;
        growthRateI = pgrowthRateI;
        carryCap = pcarryCap;
        lysisRate = plysisRate;
    }

    /**
     * accessor methods
     */
    public double getPopCountPrev()
    {
        return popCountPrev;
    }

    public double getPopCount()
    {
        return popCount;
    }

    /**
     * core methods
     */
    // update method
    public double updatePopCount(double Bu, double Bi){
        // return 1 if update is successful
        popCountPrev = popCount;
        // simple sum
        popCount = Bu + Bi;
        // complex update
        // difference equation describing update for total biofilm population size
//        double term1 = (growthRateU*Bu + growthRateI*Bi )*(1- popCount/carryCap);
//        double term2 = -lysisRate*Bl;
//        popCount += term1 + term2;
        // if popCount is less than 1, it's effectively 0
        if(popCount < 1){
            popCount = 0;
        }
        // return updated value
        return popCount;
    }

    /**
     * term-calculation methods
     */
    // calculate term representing portion of susceptible uninfected subpopulation
    public double getTheta(double BT, double Bi, double eps){
        double subterm = eps * BT;
        double term = 0;
        if(subterm == 0){
            return term;
        }else{
            term = (subterm - Bi) / subterm;
            return term;
        }
    }

    // calculate term representing number of biofilm bacteria susceptible to infection and re-infection
    public double getTermX(double BT, double P,  double eps, double kappa){
        double term1 = kappa * P;
        double term2 = eps * BT;
        if(term1 <= term2){
            return term1;
        }else{
            return term2;
        }
    }
}