/**
 * object storing data about uninfected biofilm subpopulation
 * 
 * @author Shing Hei Zhan, University of British Columbia 2010 iGEM team
 * @version 1.0 Oct. 27, 2010
 */
public class UninfectedBiofilmPop extends TotalBiofilmPop
{
    /**
     * variables and parameters
     */
    public UninfectedBiofilmPop(double inipopCount, double pgrowthRateU, double pcarryCap)
    {
        super(inipopCount, 0, pgrowthRateU, pcarryCap, 0);
    }

    /**
     * overloads parent method
     */
    public double updatePopCount(double BT, double Bi, double P, double eps, double kappa)
    {
        // return 1 if update is successful
        popCountPrev = popCount;
        // difference equation describing update for uninfected biofilm subpopulation size
        double term1 = growthRateU * popCount * (1 - BT/carryCap);
        double term2 = -getTheta(BT, Bi, eps) * getTermX(BT, P, eps, kappa);
        popCount += term1 + term2;
        // if popCount is less than 1, it's effectively 0
        if(popCount < 1){
            popCount = 0;
        }
        // return updated value
        return popCount;
    }
}